function MODERN(case_ID)
%LOAD data for the case_ID:
[site_ID,FRN_ref_ID,FRN_samp_ID,scenario_ID,plot_ID] = ...
                                                         MODERN_run(case_ID);
[FRN_ref_inv,FRN_ref_LABEL,FRN_ld,FRN_samp_inv,FRN_samp_LABELS,...
                              comp_depth,c_scenario] = MODERN_input(site_ID);

n_ref = size(FRN_ref_inv,1);
n_samp = length(FRN_samp_inv);

%(FILE)create and open a txt-file for output:
fid = fopen(['MODERN_Outputs_',site_ID,'_case_',num2str(case_ID),'.txt'],'w');

%create Specification Matrices:
[scenario_ID_data,n_plot_data] = createSpecificationMatrices(FRN_ref_ID,...
                             FRN_samp_ID,n_ref,n_samp,scenario_ID,plot_ID);

%VALUES FOR ACCURACY:
eps = 10e-6; %Accuracy

for site = 1:n_ref
    %(INPUT)data for reference sites:
    c_FRN_ref_inv = cell2mat(FRN_ref_inv(site,:));
    c_FRN_ref_LABEL = char(FRN_ref_LABEL(site,:));    
    %(FILE)write site's name in the output file:
    fwrite(fid,sprintf('%s_%d (%s):\n',site_ID,site,c_FRN_ref_LABEL));
    
    %adapt c_FRN_ref_inv:
    c_FRN_ref_inv_adapt = c_FRN_ref_inv/FRN_ld;
    
    %depth of the current reference site:
    n_c_FRN_ref_inv = length(c_FRN_ref_inv);
    depth = n_c_FRN_ref_inv*FRN_ld;
    
    c_scenario_IDs = scenario_ID_data(site,:);
    c_n_plots = n_plot_data(site,:);
    
    x_nodes = 0:FRN_ld:depth; % for createS in the next loop
    
    FRN_samp_val_ind = 1; %"FRN_samp_val_INDex"
    for FRN_samp_val = FRN_samp_inv
       c_n_plot = c_n_plots(FRN_samp_val_ind);
       c_scenario_ID = c_scenario_IDs(FRN_samp_val_ind);
       if c_scenario_ID == 0
       curr_scenario = '';
       else
       curr_scenario = char(c_scenario(c_scenario_ID));
       end
       %CREATE integral function S (important: starts plot (1)):
        S = createS_mod(x_nodes,c_FRN_ref_inv_adapt,comp_depth,FRN_ld,...
            c_n_plot,eps,curr_scenario);
        
                             
        %"(PLOT)begin" plot integral function S (2):
        if c_n_plot>0
        figure(c_n_plot);
        subplot(1,2,1)
        title({'Integral function S(x) = F(x+comparing depth) - F(x)';...
                         ['(comparing depth = ',num2str(comp_depth),')']});
        hold on 
        axis normal, grid on,
        xlim([S(1,1) S(end,1)]),...
                          ylim([0 max(max(S(:,2))+3,max(FRN_samp_inv)+3)]),
        %integral function S:
        plot(S(:,1),S(:,2),'ko-','LineWidth',1.05);
        ylabel('FRN Inventory (Bq m^ ^{-2})');xlabel('Depth (cm)')
        end
        %"(PLOT)end"
        
        %compute Inverse Set of comp_pu_val under function S
        %(important: contains plot (3)):
        c_FRN_samp_LABEL = FRN_samp_LABELS(FRN_samp_val_ind); 
        str = computeInverseSetOfFRNSampValue(FRN_samp_val,char(c_FRN_samp_LABEL),...
                                                             S,c_n_plot,eps);
        
        %(FILE)write pre-image information for comp_pu_val in output file:
        fwrite(fid,sprintf('%s scenario: %d\n',str,c_scenario_ID));
        
        FRN_samp_val_ind = FRN_samp_val_ind + 1;
        
        %"(PLOT)begin" (4):
        if c_n_plot>0
        text(S(1,1),-10,str);
        hold off
        subplot(1,2,2)
        title(sprintf('Reference site Depth Profile:\n %s (%s) , scenario = %d',...
        c_FRN_ref_LABEL,site_ID,c_scenario_ID));
        camroll(-90)
        end
        %"(PLOT)end"
    end
end

%(FILE)close output file:
fclose(fid);
end




