%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%compute the inverse set of FRN_samp_val under S:
%input:
%FRN_samp_val     total inventory of current sampling site
%FRN_samp_LABEL label of the current sampling site
%S                nodes of function S
%c_n_plot         current plot specification 
%eps              accuracy
%output:
%str              output string, gives the inverse set of FRN_samp_val
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function str = computeInverseSetOfFRNSampValue(FRN_samp_val,FRN_samp_LABEL,...
                                                            S,c_n_plot,eps)
intersec_ranges = computeStepFunctionInverseSet(FRN_samp_val,S,eps);
ir_num = size(intersec_ranges,1);
range_marker = intersec_ranges(:,2)-intersec_ranges(:,1);
intersec_points = unique(intersec_ranges);
ip_num = length(intersec_points);

%"(PLOT)begin" plot pu_val-line on graph of integral function S:
if c_n_plot>0
    figure(c_n_plot);
    subplot(1,2,1)
    hold on
    %FRN_samp_val-line:
    line([S(1,1) S(end,1)]',FRN_samp_val*ones(2,1),'Color','red');
    %intersection points:
    plot(intersec_points,FRN_samp_val*ones(ip_num,1),'ro','LineWidth',1.05);
    %dashed grid lines from intersection points:
    X = repmat(intersec_points',2,1);
    Y = [FRN_samp_val*ones(1,ip_num);zeros(1,ip_num)];
    line(X,Y,'LineStyle','--','Color','red');
    legend('Integral function S',[FRN_samp_LABEL,' = ',num2str(FRN_samp_val)],...
        'Location','NorthEast')
end
%"(PLOT)end"

%create text with pre-image information:
str = ['MODERN Output of sampling site ',FRN_samp_LABEL,' (FRN Inv: ',num2str(FRN_samp_val),' Bq/m2) = '];
if ~isempty(intersec_ranges)
    for i=1:ir_num-1
        if range_marker(i)==0 %current range is a point
            str = [str,'{',num2str(intersec_ranges(i,1)),' cm} and '];
        else %current range is a range
            str = [str,'[',num2str(intersec_ranges(i,1)),',',...
                num2str(intersec_ranges(i,2)),' cm] and '];
        end
    end
    if range_marker(end)==0 %current range is a point
        str = [str,'{',num2str(intersec_ranges(end,1)),' cm }'];
    else %current range is a range
        str = [str,'[',num2str(intersec_ranges(end,1)),',',...
            num2str(intersec_ranges(end,2)),' cm ]'];
    end
else
    str = [str, 'No solution'];
end
end