%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%create nodes of the function S = G(x+d)-G(x)
%input:
%x,c:            measured inventories of considered reference site
%d:              depth of the samling site
%h:              layer depth of the reference site             
%c_n_plot, 
%curr_scenario:  scenario and plot specifications for the current pair
%eps:            accuracy (-->computeValueOfF)
%output:
%S:              nodes of S (S is a piecewise linear function)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function S = createS_mod(x,c,d,h,c_n_plot,eps,curr_scenario)
%create extended reference profile:
[x_ext,c_ext] = ...
createExtendedReferenceFRNInvData_mod(x,c,d,h,curr_scenario,c_n_plot);   
                                                             
%create nodes of extended F:
G_ext = createG(c_ext,x_ext);

x_emin = x_ext(1); x_emax = x_ext(end);

%create nodes of function S:
if mod(d,h) == 0 % special case: d divisible by 3
    x1 = x_emin:h:x_emax-d;
    x1_num = length(x1);
    %G_ext (x1) are the first x1_num elements of G_ext:
    G_x1 = G_ext(1:x1_num);
    %"X1_Addd First", first element of x1_add_d:
    x1_aa1 = x_emin+d;
    %position of x1_aa1 in x_ext: 
    x1_aa1_pos = find(x_ext == x1_aa1);
    %G_ext(x1_add_d): the next x1_num values of G_ext from x1_aa1_pos:
    G_x1_add_d = G_ext(x1_aa1_pos:x1_aa1_pos+x1_num-1);
    
    %nodes of S:
    S = [x1' G_x1_add_d-G_x1];    
else % general case: d is not divisible by 3
    %two arts of nodes: x1 and x2
    %x_1sta: "first element of 3-Series Through -d in [x_emin,x_emax]":
    p = x_emin+(1:h-1);
    x_1sta = p(mod(p+d,h)==0);
    %nodes x_1 are all x's in definition range of S, which are elements of 
    %3-series through -d:
    x1 = x_1sta:h:x_emax-d;% are not multiples of h ->
                                % G_ext(x1) has to be computed
    x1_num = length(x1);
    x1_add_d = x1+d;  % are multiples of h -> values of G_ext at
                                % x1_add_d are already known
    %nodes x_2 are all x's in definition range of S, which are elements of
    %3-series through 0:
    x2 = x_emin:h:x_emax-d;% are multiples of h -> values of
                                % F_ext at x2 are already known
    x2_num = length(x2);
    x2_add_d = x2+d;  % are not multiples of h ->
                                % F_ext(x2_add_d) has to be computed
    
    %G_ext (x1_add_d):
    %"Position in x_ext of X1_Add_d(1)":
    pos_x1aa1 = find(x_ext == x1_add_d(1)); 
    G_x1_add_d = G_ext(pos_x1aa1:pos_x1aa1+x1_num-1);
    %G_ext(x2): are the first x2_num elements of G_ext:
    G_x2 = G_ext(1:x2_num);
    %G_ext (x2_add_d):
    G_x2_add_d = zeros(x2_num,1);
    for i=1:x2_num
        G_x2_add_d(i) = ...
                        computeValueOfG (x2_add_d(i),G_ext,x_ext,eps);
    end
    %G_ext(x1):
    G_x1 = zeros(x1_num,1);
    for i=1:x1_num
        G_x1(i) = computeValueOfG (x1(i),G_ext,x_ext,eps);
    end
    
    %S(x1):
    S_x1 = G_x1_add_d - G_x1;
    %S(x2):
    S_x2 = G_x2_add_d - G_x2;
    %nodes of S:
    S = [x1' S_x1; x2' S_x2];
    S = sortrows(S,1);
end
end

