%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%create matrices with specification data:
%input:
%FRN_ref_ID,FRN_samp_ID,n_ref,n_samp,scenario_ID,plot_ID:
%                     specifications of the current case
%output: 
%scenario_ID_data     matrix of size (n_ref x n_samp); contains scenario -
%                     specifications for all reference-sampling pairs;
%                     scenario_ID_data(c_FRN_ref_ID,c_FRN_samp_ID) is
%                     scenario_ID ( = index of scenario in input_data) or
%                     0 (corresponds to the empty case ''). 
%n_plot_data          matrix of size (n_ref x n_samp); contains plot speci-
%                     fications for all reference-sampling pairs;
%                     n_plot_data(c_FRN_ref_ID,c_FRN_samp_ID) is a number.
%                     if positive: plot current pair in figure with this 
%                     number; otherwise - no plot
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [scenario_ID_data,n_plot_data] = ...
  createSpecificationMatrices(FRN_ref_ID,FRN_samp_ID,n_ref,n_samp,...
                                                       scenario_ID,plot_ID)
%scenario_ID_data: default value is 0
scenario_ID_data = zeros(n_ref,n_samp);
%plot modes: default plot number is 0
n_plot_data = zeros(n_ref,n_samp);

if ~isempty(FRN_ref_ID)
    %prove if input data exceed the allowed values (n_ref and n_samp)
    flag = sum(FRN_ref_ID>n_ref)+sum(FRN_samp_ID>n_samp);
    if flag==0
        %prove if sizes of input data coincide:
        if length(FRN_ref_ID)==length(FRN_samp_ID)
            n_pairs = length(FRN_ref_ID);
            for i = 1:n_pairs
                c_FRN_ref_ID = FRN_ref_ID(i);
                c_FRN_samp_ID = FRN_samp_ID(i);
               % scenario_data(c_FRN_ref_ID,c_FRN_samp_ID) = scenarios(i);
                 scenario_ID_data(c_FRN_ref_ID,c_FRN_samp_ID) = scenario_ID(i);
               if plot_ID(i)>0 % if curr plot nmbr is nonzero
                    % give unique number for plot figure:
                    n_plot_data(c_FRN_ref_ID,c_FRN_samp_ID) = ...
                        c_FRN_ref_ID*(n_ref-1)+c_FRN_samp_ID;
                end
            end
        else
            error('input is incorrect:the sizes of FRN_ref_ID and FRN_samp_ID do not coincide!');
        end
    else
        error('input is incorrect: some values in FRN_ref_ID and FRN_samp_ID are not admissible');
    end
end
end